==> pureml-0.4.5-py3-none-any.whl: pureml/components/log/tabular.py <==
from pathlib import Path
from typing import Optional
import jwt
import requests

# import typer
from rich import print
from rich.syntax import Syntax

import os
import json
import typing

from urllib.parse import urljoin

from pureml.cli.helpers import get_auth_headers

from . import get_org_id

from pureml.schema import PathSchema, BackendSchema, ContentTypeHeader
from joblib import Parallel, delayed

path_schema = PathSchema()
backend_schema = BackendSchema()
#path_schema = PathSchema().get_instance()
#backend_schema = BackendSchema().get_instance()


def details(
    model_name: str, model_version: str = "latest", name: str = ""
):
    """This function returns the details of the tabular for a given model

    Parameters
    ----------
    model_name : str
        The name of the model you want to get the tabular details for
    model_version: str
        The version of the model
    name : str
        The name of the tabular.

    """

    org_id = get_org_id()

    url = "org/{}/model/{}/version/{}/log".format(
        org_id, model_name, model_version
    )
    url = urljoin(backend_schema.BASE_URL, url)

    headers = get_auth_headers(content_type=ContentTypeHeader.APP_FORM_URL_ENCODED)

    response = requests.get(url, headers=headers)

    if response.status_code == 200:
        res_text = json.loads(response.text)

        if len(res_text) == 0:
            print("[yellow] No Tabular have been found for the model")
            print(res_text)
            return
        else:
            print("[green]Tabular have been found for the model")
            print(res_text)
            return res_text

    else:
        print("[orange]Unable to obtain the tabular details")
        print(response.text)
        return


def add(
    tabular: str, model_name: str, model_version: str = "latest"
) -> str:
    """`add` function takes in the path of the tabular, name of the tabular and the model name and
    registers the tabular

    Parameters
    ----------
    tabular : str
        The path to the tabular file.
    name : str
        The name of the tabular.
    model_name : str
        The name of the model you want to add Tabular to.
    model_version: str
        The version of the model

    Returns
    -------
        The response is a JSON object

    """

    org_id = get_org_id()

    url = "org/{}/model/{}/version/{}/log".format(
        org_id, model_name, model_version
    )
    url = urljoin(backend_schema.BASE_URL, url)

    headers = get_auth_headers(content_type=ContentTypeHeader.APP_FORM_URL_ENCODED)

    files = {}
    for file_name, file_path in tabular.items():

        if os.path.isfile(file_path):
            files[file_name] = open(file_path, "rb")
        else:
            print("[orange] Tabular", file_name, "does not exist at the given path")

    data = {"name_path_mapping": tabular}

    response = requests.post(url, data=data, files=files, headers=headers)

    if response.status_code == 200:
        print(f"[green]tabulars have been registered!")

    else:
        print(f"[orange]tabulars have not been registered!")
        print(response.text)

    return response.text


def fetch(
    model_name: str, model_version: str = "latest", name: str = ""
):
    """It fetches the tabular from the server and stores it in the local directory

    Parameters
    ----------
    model_name : str
        The name of the model you want to fetch the tabular from.
    model_version: str
        The version of the model
    name : str
        The name of the tabular to be fetched. If not specified, all tabulars will be fetched.

    Returns
    -------
        The response text is being returned.

    """

    org_id = get_org_id()

    def fetch_tabular(tabular_details: dict):

        url = tabular_details["location"]
        file_path_temp = tabular_details["path"]
        file_name = file_path_temp.split(os.path.sep)[-1]
        save_path = os.path.join(path_schema.PATH_TABULAR_DIR, file_name)
        print("save path", save_path)

        name_fetched = tabular_details["tabular"]

        headers = get_auth_headers(content_type=ContentTypeHeader.APP_FORM_URL_ENCODED)

        print("tabular url", url)

        # response = requests.get(url, headers=headers)
        response = requests.get(url)

        print(response.status_code)

        if response.status_code == 200:
            print("[green] tabular {} has been fetched".format(name_fetched))

            save_dir = os.path.dirname(save_path)

            os.makedirs(save_dir, exist_ok=True)

            tabular_bytes = response.content

            open(save_path, "wb").write(tabular_bytes)

            print(
                "[green] tabular {} has been stored at {}".format(
                    name_fetched, save_path
                )
            )

            return response.text
        else:
            print("[orange] Unable to fetch the tabular")

            return response.text

    tabular_details = details(
        model_name=model_name,
        name=name,
        model_version=model_version,
    )

    if tabular_details is None:
        return

    if type(tabular_details) is dict:

        res_text = fetch_tabular(tabular_details)

    elif type(tabular_details) is list:
        res_text = Parallel(n_jobs=-1)(
            delayed(fetch_tabular)(art_det) for art_det in tabular_details
        )

    return res_text


# def delete(
#     name: str, model_name: str, model_version: str = "latest"
# ) -> str:
#     """`delete()` deletes an tabular from a model

#     Parameters
#     ----------
#     name : str
#         The name of the tabular you want to delete.
#     model_name : str
#         The name of the model you want to delete the tabular from
#     model_version: str
#         The version of the model

#     """

#     user_token = get_token()
#     org_id = get_org_id()

#     url = "org/{}/model/{}/version/{}/log".format(
#         org_id, model_name, model_version
#     )
#     url = urljoin(backend_schema.BASE_URL, url)

#     headers = {
#         "Content-Type": "application/x-www-form-urlencoded",
#         "Authorization": "Bearer {}".format(user_token),
#     }

#     # tabular_details = details(model_name=model_name, tabular=tabular)

#     # if tabular_details is None:
#     #     print('[orange] Unable to find tabular details')
#     #     return

#     response = requests.delete(url, headers=headers)

#     if response.status_code == 200:
#         print(f"[green]tabular has been deleted")

#     else:
#         print(f"[orange]Unable to delete tabular")

#     return response.text

==> pureml-0.4.7-py3-none-any.whl: pureml/components/log/tabular.py <==
import json
import os
from urllib.parse import urljoin

import requests
from joblib import Parallel, delayed

# import typer
from rich import print

from pureml.cli.helpers import get_auth_headers
from pureml.components import get_org_id
from pureml.schema.backend import BackendSchema
from pureml.schema.paths import PathSchema
from pureml.schema.request import ContentTypeHeader

path_schema = PathSchema()
backend_schema = BackendSchema()
# path_schema = PathSchema().get_instance()
# backend_schema = BackendSchema().get_instance()


def details(model_name: str, model_version: str = "latest", name: str = ""):
    """This function returns the details of the tabular for a given model

    Parameters
    ----------
    model_name : str
        The name of the model you want to get the tabular details for
    model_version: str
        The version of the model
    name : str
        The name of the tabular.

    """

    org_id = get_org_id()

    url = "org/{}/model/{}/version/{}/log".format(
        org_id, model_name, model_version
    )
    url = urljoin(backend_schema.BASE_URL, url)

    headers = get_auth_headers(
        content_type=ContentTypeHeader.APP_FORM_URL_ENCODED
    )

    response = requests.get(url, headers=headers)

    if response.status_code == 200:
        res_text = json.loads(response.text)

        if len(res_text) == 0:
            print("[yellow] No Tabular have been found for the model")
            print(res_text)
            return
        else:
            print("[green]Tabular have been found for the model")
            print(res_text)
            return res_text

    else:
        print("[orange]Unable to obtain the tabular details")
        print(response.text)
        return


def add(tabular: str, model_name: str, model_version: str = "latest") -> str:
    """`add` function takes in the path of the tabular, name of the tabular and the model name and
    registers the tabular

    Parameters
    ----------
    tabular : str
        The path to the tabular file.
    name : str
        The name of the tabular.
    model_name : str
        The name of the model you want to add Tabular to.
    model_version: str
        The version of the model

    Returns
    -------
        The response is a JSON object

    """

    org_id = get_org_id()

    url = "org/{}/model/{}/version/{}/log".format(
        org_id, model_name, model_version
    )
    url = urljoin(backend_schema.BASE_URL, url)

    headers = get_auth_headers(
        content_type=ContentTypeHeader.APP_FORM_URL_ENCODED
    )

    files = {}
    for file_name, file_path in tabular.items():

        if os.path.isfile(file_path):
            files[file_name] = open(file_path, "rb")
        else:
            print(
                "[orange] Tabular",
                file_name,
                "does not exist at the given path",
            )

    data = {"name_path_mapping": tabular}

    response = requests.post(url, data=data, files=files, headers=headers)

    if response.status_code == 200:
        print(f"[green]tabulars have been registered!")

    else:
        print(f"[orange]tabulars have not been registered!")
        print(response.text)

    return response.text


def fetch(model_name: str, model_version: str = "latest", name: str = ""):
    """It fetches the tabular from the server and stores it in the local directory

    Parameters
    ----------
    model_name : str
        The name of the model you want to fetch the tabular from.
    model_version: str
        The version of the model
    name : str
        The name of the tabular to be fetched. If not specified, all tabulars will be fetched.

    Returns
    -------
        The response text is being returned.

    """

    get_org_id()

    def fetch_tabular(tabular_details: dict):

        url = tabular_details["location"]
        file_path_temp = tabular_details["path"]
        file_name = file_path_temp.split(os.path.sep)[-1]
        save_path = os.path.join(path_schema.PATH_TABULAR_DIR, file_name)
        print("save path", save_path)

        name_fetched = tabular_details["tabular"]

        headers = get_auth_headers(
            content_type=ContentTypeHeader.APP_FORM_URL_ENCODED
        )

        print("tabular url", url)

        # response = requests.get(url, headers=headers)
        response = requests.get(url)

        print(response.status_code)

        if response.status_code == 200:
            print("[green] tabular {} has been fetched".format(name_fetched))

            save_dir = os.path.dirname(save_path)

            os.makedirs(save_dir, exist_ok=True)

            tabular_bytes = response.content

            open(save_path, "wb").write(tabular_bytes)

            print(
                "[green] tabular {} has been stored at {}".format(
                    name_fetched, save_path
                )
            )

            return response.text
        else:
            print("[orange] Unable to fetch the tabular")

            return response.text

    tabular_details = details(
        model_name=model_name,
        name=name,
        model_version=model_version,
    )

    if tabular_details is None:
        return

    if type(tabular_details) is dict:

        res_text = fetch_tabular(tabular_details)

    elif type(tabular_details) is list:
        res_text = Parallel(n_jobs=-1)(
            delayed(fetch_tabular)(art_det) for art_det in tabular_details
        )

    return res_text


# def delete(
#     name: str, model_name: str, model_version: str = "latest"
# ) -> str:
#     """`delete()` deletes an tabular from a model

#     Parameters
#     ----------
#     name : str
#         The name of the tabular you want to delete.
#     model_name : str
#         The name of the model you want to delete the tabular from
#     model_version: str
#         The version of the model

#     """

#     user_token = get_token()
#     org_id = get_org_id()

#     url = "org/{}/model/{}/version/{}/log".format(
#         org_id, model_name, model_version
#     )
#     url = urljoin(backend_schema.BASE_URL, url)

#     headers = {
#         "Content-Type": "application/x-www-form-urlencoded",
#         "Authorization": "Bearer {}".format(user_token),
#     }

#     # tabular_details = details(model_name=model_name, tabular=tabular)

#     # if tabular_details is None:
#     #     print('[orange] Unable to find tabular details')
#     #     return

#     response = requests.delete(url, headers=headers)

#     if response.status_code == 200:
#         print(f"[green]tabular has been deleted")

#     else:
#         print(f"[orange]Unable to delete tabular")

#     return response.text
